summaryrefslogtreecommitdiff
path: root/src/daemon/dlt_daemon_client.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/daemon/dlt_daemon_client.h')
-rw-r--r--src/daemon/dlt_daemon_client.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/daemon/dlt_daemon_client.h b/src/daemon/dlt_daemon_client.h
index ecfd4d0..80821d2 100644
--- a/src/daemon/dlt_daemon_client.h
+++ b/src/daemon/dlt_daemon_client.h
@@ -104,8 +104,8 @@ int dlt_daemon_client_send(int sock,
* @param daemon pointer to dlt daemon structure
* @param daemon_local pointer to dlt daemon local structure
* @param msg pointer to response message
* @param appid pointer to application id to be used in response message
* @param contid pointer to context id to be used in response message
* @param verbose if set to true verbose information is printed out.
* @return -1 if there is an error or buffer is full
*/
@@ -113,8 +113,8 @@ int dlt_daemon_client_send_control_message(int sock,
DltDaemon *daemon,
DltDaemonLocal *daemon_local,
DltMessage *msg,
- char *appid,
- char *contid,
+ char *apid,
+ char *ctid,
int verbose);
/**
* Process and generate response to received get log info control message
@@ -104,8 +104,8 @@ int dlt_daemon_client_send(int sock,
* @param daemon_local pointer to dlt daemon local structure
* @param msg pointer to response message
- * @param appid pointer to application id to be used in response message
- * @param contid pointer to context id to be used in response message
+ * @param apid pointer to application id to be used in response message
+ * @param ctid pointer to context id to be used in response message
* @param verbose if set to true verbose information is printed out.
* @return -1 if there is an error or buffer is full